==> pinot-common-1.0.0-sources.jar: org/apache/pinot/common/proto/PinotMailboxGrpc.java <==
package org.apache.pinot.common.proto;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.53.0)",
    comments = "Source: mailbox.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PinotMailboxGrpc {

  private PinotMailboxGrpc() {}

  public static final String SERVICE_NAME = "org.apache.pinot.common.proto.PinotMailbox";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent,
      org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "open",
      requestType = org.apache.pinot.common.proto.Mailbox.MailboxContent.class,
      responseType = org.apache.pinot.common.proto.Mailbox.MailboxStatus.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent,
      org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod() {
    io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent, org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod;
    if ((getOpenMethod = PinotMailboxGrpc.getOpenMethod) == null) {
      synchronized (PinotMailboxGrpc.class) {
        if ((getOpenMethod = PinotMailboxGrpc.getOpenMethod) == null) {
          PinotMailboxGrpc.getOpenMethod = getOpenMethod =
              io.grpc.MethodDescriptor.<org.apache.pinot.common.proto.Mailbox.MailboxContent, org.apache.pinot.common.proto.Mailbox.MailboxStatus>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "open"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Mailbox.MailboxContent.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Mailbox.MailboxStatus.getDefaultInstance()))
              .setSchemaDescriptor(new PinotMailboxMethodDescriptorSupplier("open"))
              .build();
        }
      }
    }
    return getOpenMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PinotMailboxStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxStub>() {
        @java.lang.Override
        public PinotMailboxStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxStub(channel, callOptions);
        }
      };
    return PinotMailboxStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PinotMailboxBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxBlockingStub>() {
        @java.lang.Override
        public PinotMailboxBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxBlockingStub(channel, callOptions);
        }
      };
    return PinotMailboxBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PinotMailboxFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxFutureStub>() {
        @java.lang.Override
        public PinotMailboxFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxFutureStub(channel, callOptions);
        }
      };
    return PinotMailboxFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class PinotMailboxImplBase implements io.grpc.BindableService {

    /**
     */
    public io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxContent> open(
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus> responseObserver) {
      return io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getOpenMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getOpenMethod(),
            io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
              new MethodHandlers<
                org.apache.pinot.common.proto.Mailbox.MailboxContent,
                org.apache.pinot.common.proto.Mailbox.MailboxStatus>(
                  this, METHODID_OPEN)))
          .build();
    }
  }

  /**
   */
  public static final class PinotMailboxStub extends io.grpc.stub.AbstractAsyncStub<PinotMailboxStub> {
    private PinotMailboxStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxStub(channel, callOptions);
    }

    /**
     */
    public io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxContent> open(
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus> responseObserver) {
      return io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getOpenMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class PinotMailboxBlockingStub extends io.grpc.stub.AbstractBlockingStub<PinotMailboxBlockingStub> {
    private PinotMailboxBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class PinotMailboxFutureStub extends io.grpc.stub.AbstractFutureStub<PinotMailboxFutureStub> {
    private PinotMailboxFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_OPEN = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final PinotMailboxImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(PinotMailboxImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_OPEN:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.open(
              (io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class PinotMailboxBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PinotMailboxBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.pinot.common.proto.Mailbox.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PinotMailbox");
    }
  }

  private static final class PinotMailboxFileDescriptorSupplier
      extends PinotMailboxBaseDescriptorSupplier {
    PinotMailboxFileDescriptorSupplier() {}
  }

  private static final class PinotMailboxMethodDescriptorSupplier
      extends PinotMailboxBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    PinotMailboxMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PinotMailboxGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PinotMailboxFileDescriptorSupplier())
              .addMethod(getOpenMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> pinot-common-1.3.0-sources.jar: org/apache/pinot/common/proto/PinotMailboxGrpc.java <==
package org.apache.pinot.common.proto;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.69.0)",
    comments = "Source: mailbox.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class PinotMailboxGrpc {

  private PinotMailboxGrpc() {}

  public static final java.lang.String SERVICE_NAME = "org.apache.pinot.common.proto.PinotMailbox";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent,
      org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "open",
      requestType = org.apache.pinot.common.proto.Mailbox.MailboxContent.class,
      responseType = org.apache.pinot.common.proto.Mailbox.MailboxStatus.class,
      methodType = io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent,
      org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod() {
    io.grpc.MethodDescriptor<org.apache.pinot.common.proto.Mailbox.MailboxContent, org.apache.pinot.common.proto.Mailbox.MailboxStatus> getOpenMethod;
    if ((getOpenMethod = PinotMailboxGrpc.getOpenMethod) == null) {
      synchronized (PinotMailboxGrpc.class) {
        if ((getOpenMethod = PinotMailboxGrpc.getOpenMethod) == null) {
          PinotMailboxGrpc.getOpenMethod = getOpenMethod =
              io.grpc.MethodDescriptor.<org.apache.pinot.common.proto.Mailbox.MailboxContent, org.apache.pinot.common.proto.Mailbox.MailboxStatus>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "open"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Mailbox.MailboxContent.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.pinot.common.proto.Mailbox.MailboxStatus.getDefaultInstance()))
              .setSchemaDescriptor(new PinotMailboxMethodDescriptorSupplier("open"))
              .build();
        }
      }
    }
    return getOpenMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static PinotMailboxStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxStub>() {
        @java.lang.Override
        public PinotMailboxStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxStub(channel, callOptions);
        }
      };
    return PinotMailboxStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static PinotMailboxBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxBlockingStub>() {
        @java.lang.Override
        public PinotMailboxBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxBlockingStub(channel, callOptions);
        }
      };
    return PinotMailboxBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static PinotMailboxFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<PinotMailboxFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<PinotMailboxFutureStub>() {
        @java.lang.Override
        public PinotMailboxFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new PinotMailboxFutureStub(channel, callOptions);
        }
      };
    return PinotMailboxFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxContent> open(
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus> responseObserver) {
      return io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getOpenMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service PinotMailbox.
   */
  public static abstract class PinotMailboxImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return PinotMailboxGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service PinotMailbox.
   */
  public static final class PinotMailboxStub
      extends io.grpc.stub.AbstractAsyncStub<PinotMailboxStub> {
    private PinotMailboxStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxStub(channel, callOptions);
    }

    /**
     */
    public io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxContent> open(
        io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus> responseObserver) {
      return io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getOpenMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service PinotMailbox.
   */
  public static final class PinotMailboxBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<PinotMailboxBlockingStub> {
    private PinotMailboxBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxBlockingStub(channel, callOptions);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service PinotMailbox.
   */
  public static final class PinotMailboxFutureStub
      extends io.grpc.stub.AbstractFutureStub<PinotMailboxFutureStub> {
    private PinotMailboxFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected PinotMailboxFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new PinotMailboxFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_OPEN = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_OPEN:
          return (io.grpc.stub.StreamObserver<Req>) serviceImpl.open(
              (io.grpc.stub.StreamObserver<org.apache.pinot.common.proto.Mailbox.MailboxStatus>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getOpenMethod(),
          io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
            new MethodHandlers<
              org.apache.pinot.common.proto.Mailbox.MailboxContent,
              org.apache.pinot.common.proto.Mailbox.MailboxStatus>(
                service, METHODID_OPEN)))
        .build();
  }

  private static abstract class PinotMailboxBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    PinotMailboxBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.pinot.common.proto.Mailbox.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("PinotMailbox");
    }
  }

  private static final class PinotMailboxFileDescriptorSupplier
      extends PinotMailboxBaseDescriptorSupplier {
    PinotMailboxFileDescriptorSupplier() {}
  }

  private static final class PinotMailboxMethodDescriptorSupplier
      extends PinotMailboxBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    PinotMailboxMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (PinotMailboxGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new PinotMailboxFileDescriptorSupplier())
              .addMethod(getOpenMethod())
              .build();
        }
      }
    }
    return result;
  }
}
